@@ -20,7 +20,6 @@ WSGI middleware for OpenStack API controllers.
 
 from oslo_log import log as logging
 import routes
-import six
 import stevedore
 import webob.dec
 import webob.exc
@@ -54,7 +53,7 @@ class FaultWrapper(base_wsgi.Middleware):
                                   status, webob.exc.HTTPInternalServerError)()
 
     def _error(self, inner, req):
-        LOG.exception(_LE("Caught error: %s"), six.text_type(inner))
+        LOG.exception(_LE("Caught error: %s"), inner)
 
         safe = getattr(inner, 'safe', False)
         headers = getattr(inner, 'headers', None)
@@ -222,7 +221,7 @@ class APIRouterV21(base_wsgi.Router):
     def api_extension_namespace():
         return 'nova.api.v21.extensions'
 
-    def __init__(self, init_only=None):
+    def __init__(self):
         def _check_load_extension(ext):
             return self._register_extension(ext)
 
