@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_utils import strutils
 import webob.exc
 
 from nova.api.openstack import api_version_request
@@ -22,17 +23,18 @@ from nova.api import validation
 from nova import compute
 from nova import exception
 from nova.i18n import _
+from nova.policies import services as services_policies
 from nova import servicegroup
 from nova import utils
 
 ALIAS = "os-services"
-authorize = extensions.os_compute_authorizer(ALIAS)
 
 
 class ServiceController(wsgi.Controller):
 
     def __init__(self):
         self.host_api = compute.HostAPI()
+        self.aggregate_api = compute.api.AggregateAPI()
         self.servicegroup_api = servicegroup.API()
         self.actions = {"enable": self._enable,
                         "disable": self._disable,
@@ -42,7 +44,7 @@ class ServiceController(wsgi.Controller):
         api_services = ('nova-osapi_compute', 'nova-ec2', 'nova-metadata')
 
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(services_policies.BASE_POLICY_NAME)
 
         _services = [
            s
@@ -131,7 +133,7 @@ class ServiceController(wsgi.Controller):
     def _forced_down(self, body, context):
         """Set or unset forced_down flag for the service"""
         try:
-            forced_down = body["forced_down"]
+            forced_down = strutils.bool_from_string(body["forced_down"])
         except KeyError:
             msg = _('Missing forced_down field')
             raise webob.exc.HTTPBadRequest(explanation=msg)
@@ -155,7 +157,7 @@ class ServiceController(wsgi.Controller):
     def _perform_action(self, req, id, body, actions):
         """Calculate action dictionary dependent on provided fields"""
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(services_policies.BASE_POLICY_NAME)
 
         try:
             action = actions[id]
@@ -170,7 +172,7 @@ class ServiceController(wsgi.Controller):
     def delete(self, req, id):
         """Deletes the specified service."""
         context = req.environ['nova.context']
-        authorize(context)
+        context.can(services_policies.BASE_POLICY_NAME)
 
         try:
             utils.validate_integer(id, 'id')
@@ -178,7 +180,17 @@ class ServiceController(wsgi.Controller):
             raise webob.exc.HTTPBadRequest(explanation=exc.format_message())
 
         try:
+            service = self.host_api.service_get_by_id(context, id)
+            # remove the service from all the aggregates in which it's included
+            if service.binary == 'nova-compute':
+                aggrs = self.aggregate_api.get_aggregates_by_host(context,
+                                                                  service.host)
+                for ag in aggrs:
+                    self.aggregate_api.remove_host_from_aggregate(context,
+                                                                  ag.id,
+                                                                  service.host)
             self.host_api.service_delete(context, id)
+
         except exception.ServiceNotFound:
             explanation = _("Service %s not found.") % id
             raise webob.exc.HTTPNotFound(explanation=explanation)
