@@ -16,18 +16,18 @@
 
 """Starter script for Nova Compute."""
 
+import shlex
 import sys
-import traceback
 
+import os_vif
 from oslo_log import log as logging
+from oslo_privsep import priv_context
 from oslo_reports import guru_meditation_report as gmr
 
+from nova.cmd import common as cmd_common
 from nova.conductor import rpcapi as conductor_rpcapi
 import nova.conf
 from nova import config
-import nova.db.api
-from nova import exception
-from nova.i18n import _LE, _LW
 from nova import objects
 from nova.objects import base as objects_base
 from nova import service
@@ -35,42 +35,24 @@ from nova import utils
 from nova import version
 
 CONF = nova.conf.CONF
-CONF.import_opt('compute_topic', 'nova.compute.rpcapi')
 LOG = logging.getLogger('nova.compute')
 
 
-def block_db_access():
-    class NoDB(object):
-        def __getattr__(self, attr):
-            return self
-
-        def __call__(self, *args, **kwargs):
-            stacktrace = "".join(traceback.format_stack())
-            LOG.error(_LE('No db access allowed in nova-compute: %s'),
-                      stacktrace)
-            raise exception.DBNotAllowed('nova-compute')
-
-    nova.db.api.IMPL = NoDB()
-
-
 def main():
     config.parse_args(sys.argv)
     logging.setup(CONF, 'nova')
+    priv_context.init(root_helper=shlex.split(utils.get_root_helper()))
     utils.monkey_patch()
     objects.register_all()
+    # Ensure os-vif objects are registered and plugins loaded
+    os_vif.initialize()
 
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    if not CONF.conductor.use_local:
-        block_db_access()
-        objects_base.NovaObject.indirection_api = \
-            conductor_rpcapi.ConductorAPI()
-    else:
-        LOG.warning(_LW('Conductor local mode is deprecated and will '
-                        'be removed in a subsequent release'))
+    cmd_common.block_db_access('nova-compute')
+    objects_base.NovaObject.indirection_api = conductor_rpcapi.ConductorAPI()
 
     server = service.Service.create(binary='nova-compute',
-                                    topic=CONF.compute_topic,
-                                    db_allowed=CONF.conductor.use_local)
+                                    topic=CONF.compute_topic)
     service.serve(server)
     service.wait()
