@@ -18,3 +18,5 @@ NET_EXTERNAL = 'router:external'
 PORTBINDING_EXT = 'Port Binding'
 VNIC_INDEX_EXT = 'VNIC Index'
 DNS_INTEGRATION = 'DNS Integration'
+AUTO_ALLOCATE_TOPO_EXT = 'Auto Allocated Topology Services'
+MULTI_NET_EXT = 'Multi Provider Network'
