@@ -37,14 +37,16 @@ class RebuildVolumeBackedSameImage(integrated_helpers._IntegratedTestBase,
         self.useFixture(nova_fixtures.CinderFixture(self))
 
     def _setup_scheduler_service(self):
+        self.useFixture(nova_fixtures.PlacementFixture())
         # Add the IsolatedHostsFilter to the list of enabled filters since it
         # is not enabled by default.
-        enabled_filters = CONF.scheduler_default_filters
+        enabled_filters = CONF.filter_scheduler.enabled_filters
         enabled_filters.append('IsolatedHostsFilter')
-        # The DiskFilter does not play nice with our fake virt environment.
+        # Remove the DiskFilter since we're using Placement for filtering on
+        # DISK_GB.
         if 'DiskFilter' in enabled_filters:
             enabled_filters.remove('DiskFilter')
-        self.flags(scheduler_default_filters=enabled_filters)
+        self.flags(enabled_filters=enabled_filters, group='filter_scheduler')
         return self.start_service('scheduler')
 
     def test_volume_backed_rebuild_same_image(self):
@@ -74,7 +76,8 @@ class RebuildVolumeBackedSameImage(integrated_helpers._IntegratedTestBase,
         # Now we mark the host that the instance is running on as isolated
         # but we won't mark the image as isolated, meaning the rebuild
         # will fail for that image on that host.
-        self.flags(isolated_hosts=[self.compute.host])
+        self.flags(isolated_hosts=[self.compute.host],
+                   group='filter_scheduler')
 
         # Now rebuild the server with the same image that was used to create
         # our fake volume.
