@@ -16,19 +16,18 @@
 
 """Tests for the testing base code."""
 
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 import six
 
+import nova.conf
 from nova import rpc
 from nova import test
 from nova.tests import fixtures
 
 LOG = logging.getLogger(__name__)
 
-CONF = cfg.CONF
-CONF.import_opt('use_local', 'nova.conductor.api', group='conductor')
+CONF = nova.conf.CONF
 
 
 class IsolationTestCase(test.TestCase):
@@ -39,7 +38,6 @@ class IsolationTestCase(test.TestCase):
 
     """
     def test_service_isolation(self):
-        self.flags(use_local=True, group='conductor')
         self.useFixture(fixtures.ServiceFixture('compute'))
 
     def test_rpc_consumer_isolation(self):
@@ -183,3 +181,23 @@ class MatchTypeTestCase(test.NoDBTestCase):
         self.assertNotEqual(matcher, World())
         self.assertNotEqual(matcher, 123)
         self.assertNotEqual(matcher, "foo")
+
+
+class ContainKeyValueTestCase(test.NoDBTestCase):
+
+    def test_contain_key_value_normal(self):
+        matcher = test.ContainKeyValue('foo', 'bar')
+
+        self.assertEqual(matcher, {123: 'nova', 'foo': 'bar'})
+        self.assertNotEqual(matcher, {'foo': 123})
+        self.assertNotEqual(matcher, {})
+
+    def test_contain_key_value_exception(self):
+        matcher = test.ContainKeyValue('foo', 'bar')
+
+        # Raise TypeError
+        self.assertNotEqual(matcher, 123)
+        self.assertNotEqual(matcher, 'foo')
+        # Raise KeyError
+        self.assertNotEqual(matcher, {1: 2, '3': 4, 5: '6'})
+        self.assertNotEqual(matcher, {'bar': 'foo'})
